---
layout: assignment
published: true

title: Fabricated Accessibility
revised: 3/23/2024

objective: Learn about physical computing & fabrication

---
# Overview

The goal of this assignment is to learn about fabrication technology and their value in designing physical accessibility aids. 

## Learning Goals / Competencies
This homework will contribute to your competency grade on 
- Accessible document presentation/creation
- Image description
- Disability model analysis

It may contribute to other competencies depending on how you approach it. 

# Basic Requirements for Project
Your goal in this project is to select a fabrication technology, learn about how it is being used to slove accessibility problems, and create a fabricated accessibility technology using that technology. There is a great deal of flexibility in what fabrication approach you use. You could, for example, use knitting (hand or machine), laser cutting (with a variety of possible hard and soft material choices), or 3D printing, among others. 

## Preparation
Several papers have talked about different uses of fabrication for accessibility including the following. 
- (3D printing and lesercutting) [Sharing is Caring: Assistive Technology Designs on Thingiverse](https://doi.org/10.1145/2702123.2702525), CHI 2015
- (3D printing) [Reprise: A Design Tool for Specifying, Generating, and Customizing 3D Printable Adaptations on Everyday Objects](https://doi.org/10.1145/2984511.2984512), UIST 2016
- (Knitting) [Stitching Together the Experiences of Disabled Knitters](https://doi.org/10.1145/3411764.3445521), CHI 2021
- (3D printing) [The Global Care Ecosystems of 3D Printed Assistive Devices](https://dl.acm.org/doi/10.1145/3537676), TACCESS 2022

In addition, there is beginning to be a literature around making fabrication more accessible, particulary to people who are blind or visually impaired (BVI) including the following.
- (laser cutting) [Daedalus in the Dark: Designing for Non-Visual Accessible Construction of Laser-Cut Architecture](https://dl.acm.org/doi/abs/10.1145/3472749.3474754?casa_token=qcWkLOy0lOUAAAAA:vQt3CFQJ7aUZDiNms5kzS6DY1jWa_hrbIr1LyZckdEg-v68L4SS8iyI8V4Sr1OE5x3h6zssZkSvm2oo), UIST 2021
- (soldering) [Putting tools in hands: Designing curriculum for a nonvisual soldering workshop](https://dl.acm.org/doi/pdf/10.1145/3373625.3418011)

You may find it valuable to read them. 

# Details

To complete this assignment you will need to do the following (we hope some of this will take place in class)

## 0. Find one or more examples of an accessibility support or accessible object you want to fabricate
There are there ways you might use fabrication in this project 
1. **Access technology**: You might use fabrication to support an accessibility need, such as making something easier to grasp or manipulate
2. **Access technology modification**: You might use fabrication to make an existing accessibility support object more aesthetically appealing or functional. For example, you might make a beautiful "skin" to decorate a cane.
3. **Everyday technology modification**: You might use fabrication to make an make a task or object that is not accessible more accessible. For example, you might create a sweater that does not bunch up or catch in the wheels when seated in a wheelchair.

You should search for examples of aids on places such as thingiverse, ravelry, and so on. You may also look on amazon or other sites that sell accessibility products but do not include open sourced fabricatable patterns for them. You may also use ideas drawn from the [slides we presented in class](../slides/3dprinting.html).

{% details Example Objects for Inspiration %}
Some examples of things that one can laser cut which serve an accessibility purpose 
- A [cookbook, or book, stand](https://bookriot.com/accessories-for-accessible-reading/)
- **A pillbox** - make with [boxes.py](https://www.festi.info/boxes.py/)
- A **one handed cutting board** with edges and pins to hold things in place
- A [jar opener](https://www.thingiverse.com/thing:40131) and another [jar opener](https://www.thingiverse.com/thing:2801157)
- [iPad keyguard](https://www.thingiverse.com/thing:1365497)
- [Key handle](https://www.thingiverse.com/thing:2802082)
- [Bag holder](https://www.instructables.com/Making-a-laser-cut-bag-holder/)
- Something to [hold a book open](https://www.etsy.com/listing/883330413/book-buddy-book-holder-wood-thumb-page)
- [Fidget spinners](https://www.instructables.com/Laser-Cut-MDF-Fidget-Spinner/)
{% enddetails %}

## 1. Manufacture it 
1. Make it your own: Create a model or a pattern from scratch, or personalize the object you found in some way.
2. Create a low cost prototype: Create a low-cost prototype (such as printing it on paper) to double check it
3. Fabricate it
4. "Finish" it (i.e. sand and/or assemble  your object

## 2. Reflect on what you learned

<!-- - Create a Ravelry, Thingiverse or Instructables page for your project with a brief description of the project, a video, the model or pattern used for fabrication, any a similar technology in a paper, product site, or open source repository that you based it on, and the final project. -->
- Write a 1 page reflection 
  <!-- - Include a link to your external page -->
  - Analyzing what you created using positive disability principles (or specify if a principle doesn't apply)
    1. Is it ableist
    2. What parts of the work are accessible and what are not (for example, are both design tools, and their outputs accessible?)
    3. Are people with disabilities engaged in guiding this work? At what stages?
    4. Is it being used to give control and improve agency for people with disabilities
    5. Is it addressing the whole community (intersectionality, multiple disabled people, multiply disabled people)
  - What are three things you learned from the manufacturing and finishing process?
  - An appendix with your model or pattern, a picture of your prototype, and a picture of your final manufactured object. 
  - An appendix with a list of the competencies you wish to be assessed on other than Accessible document presentation/creation; Image description; and Disability model analysis, and any additional information needed to be assessed (as specified in [the competencies](index.html#competencies)). For example, if you find a first person account, you could include a link to the first person account and also meet the requirements for familiar with a range of AT by adding an appendix describing the range of users and strengths and weaknesses of the AT. 

# Hand in

Turn your writeup in on [Canvas]({{site.canvas}})
