---
layout: assignment
published: true

title: AT Around Us
description: Find and learn about how people with disabilities use a variety of accessibility technologies
revised: 7/24/2024 (updated FAQ on 9/30/2024; updated resources on 10/5/2024)
---

* TOC
{:toc}


# Overview

The goal of this assignment is to give you experience with seeking out first-person accounts of disability experiences with technology. It will also give you experience with presenting accessibly and expose you to a wide range of accessibility technologies. 


## Competencies
This homework may contribute to your competency grade on 
- Finding first person accounts
- Image description
- Accessible presenting
- Accessible document creation

## Length and Difficulty
Students in the past have reported that this assignment takes about 3 hours. However, in our experience many students have had to make multiple attempts to fully meet the competency for finding first person accounts. We recommend you carefully read the requirements for that below, and check in if you have a question. Many students also found presenting accessibly difficult, particularly with respect to how to describe images on their slides. We recommend that you practice this ahead of time. 
Some things students have told us about this assignment:
- "I like the requirement of looking at real world tools or tech, expanding beyond the computer."
- "I enjoy doing this because I watched a few videos and learned a lot of accessibility technology tools [and why we have them]."
- "It was surprisingly difficult to find first-person accounts for the tech I chose."

# Turnin
1. Complete the assignment as described below 
2. [Submit]({{site.submit}}) your writeup using this [template outline](finding-accessibility-template.html).
3. Turn the slides in by adding them to the shared slide deck posted on [Canvas]({{site.submit}}) for this assignment
4. You will also present at one of those slides in class

## Example
We have provided two examples: There is an example writeup at the end of the [template writeup](finding-accessibility-template.html).
An example slide can be found at the start of the slide deck (posted on [Canvas]({{site.canvas}})) that you will add your slide to. 

# Assignment FAQ

## I know or interviewed somebody who uses AT for their accessibility needs. Does talking to them count as finding a first person account?

Yes, this counts as a first-person account, but not for this assignment unless you are able to submit a transcript or video testimony for us to review (unlikely under IRB rules). 

## Does asking an other student or TA in this class who may use AT count as first person response?

No. This does not count as a first-person account. It is additional burden on the student who you are asking to help out in this capacity.

## Where can I find examples of first person accounts

Youtube is a great place to start. You can also look in reddits for specific disability communities

## Where can I get ideas about what types of technologies people with disabilities use

One great resource is [AskJan](https://askjan.org/sitsol/index.cfm). This is a website that helps people with disabilities find out about accommodations that can help them succeed in the workforce. Their mission statement: "JAN helps employers recognize the valuable contributions that qualified workers with disabilities add to the workforce by providing accommodation solutions, trusted strategies, and practical guidance on the Americans with Disabilities Act (ADA). Job accommodations play a vital role in creating inclusive workplaces, advancing the goals of the ADA, and increasing employment opportunities for people with disabilities."

Another great resource is  from the [Adaptech Database](https://adaptech.org/fandi/products/operating-system/mac-os/?v=categories). This is a database of accessibility technology. "The Adaptech Research Network consists of a team of academics, students and consumers. We conduct research involving college and university students with a variety of disabilities in Canada. We are based at Dawson College in Montreal and have been in existence since 1996." 

# Details

To complete this assignment you will need to do the following: 

## 0. Learn about how to present accessibly

Watch [a video about presenting
accessibly](https://www.youtube.com/watch?v=L9TxhGv91kc) by Kyle
Rector and look at [DOIT's guidance](https://www.washington.edu/doit/tips-delivering-accessible-presentation) on accessible presenting. Review information about [describing images](https://webaim.org/techniques/alttext/) and [describing people](https://www.youtube.com/watch?v=By6nzFefcxs) in images verbally (during a presentation) or in text. Make sure you don't use [ableist language](https://www.popsugar.com/fitness/common-phrases-that-are-ableist-48080654). Stay within the required time.  Other details on this requirement can be found in the [canvas outcomes]({{site.canvas}}/outcomes)

<iframe width="560" height="315" src="https://www.youtube.com/embed/L9TxhGv91kc?si=gTEEKwMk6C5rAiW5" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>

## 1. Select two examples of an accessibility technology or disability hack

Select two examples of accessibility technology, or disability hack, that you will be presenting about. An accessibility technology is something that is used by a person with a disability to increase accessibility. It can be something that is included in the infrastructure (such as a [curb cut](https://en.wikipedia.org/wiki/Curb_cut)) or something that is used by an individual (such as [Proloque2Go](https://www.talktometechnologies.com/pages/proloquo2go), a symbol-based communication system), or something that was not designed for accessibility but is useful (such as these [5 disability life hacks](https://www.spinalcord.com/blog/5-inexpensive-disability-life-wheelchair-hacks))

When you pick, consider **these requirements**
- One technology should improve computer access (such as [sticky keys](https://en.wikipedia.org/wiki/Sticky_keys)).
- One should improve access to "the world" at large (such as Microsoft's [Seeing AI](https://www.microsoft.com/en-us/ai/seeing-ai)).
- At least one should involve computers in some way (such as [sticky keys](https://en.wikipedia.org/wiki/Sticky_keys)).
- Try not to pick the same thing as someone else in the class.
- Do not choose really really common things (like elevators and glasses). 
- Do not pick a [*Disability Dongle*](https://blog.castac.org/2022/04/disability-dongle/)
- At least one of your chosen technologies is something you can try yourself

In addition, you should pick something that *expands your knowledge of accessibility technology.* You should include two different technologies that you are not already familiar with. Other considerations that could help when searching for technology:
- Does it address infrastructure (like curb cuts) or is it more individual (like a screen magnifier)? 
- Was it designed for the disability community (like a screen reader) or is it a mainstream technology being used to address accessibility needs (like [voice assistants have](https://dl.acm.org/doi/pdf/10.1145/3173574.3174033)).

## 2. Find  First Person Experiences

Find first person accounts *by a person with a disability* that is *not an advertisement* describing each technology and how they use it. For example, here is a [personal perspective on audio crosswalks](https://www.youtube.com/watch?v=xPlsYhU1HBU) and here is an interview with two black AAC users about their experiences using AAC technology (start at 00:16:00)

<iframe width="560" height="315" src="https://www.youtube.com/embed/iTSAK4yRf5A" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe>

Ideally, you will find a video account showing the technology in use. Try searching for "howto" or try searching first for vloggers who have a disability, and then looking in their channels for technology reviews. Also ask for help on our [class discussion site]({{site.discussion}}) if you are having trouble. If you cannot find a video, you can look for a written account, such as a blog or review. In this case, it still needs to be written by a person with a disability who would benefit from the AT that you are trying to learn about. This may influence your choice of technologies, it is OK to iterate. 

## 3. Try it yourself 

While some technologies may be expensive or hard to get, many accessibility technologies are easily available and some are even re-purposed everyday items. Try at least one of the technologies you find yourself. 


## 5. Create one or two *accessible* slides slides for each technology you found

You will create two accessible slides (per AT) in a shared slide deck posted in the [Class Discussion]({{site.discussion}}/3515497). Your slide should include 
- A summary of the AT you researched 
- Information about its audience (range of disabilities that use it)
- A picture of it
- A link to the first person account you found
- Something you learned from the first person account about its strengths and weaknesses

Make sure your slides are accessible, following best practices. More details on expectations for this are available in the [Canvas Outcomes]({{site.canvas}}/outcomes) and described in the [slides on presenting accessibly]({{site.baseurl}}/slides/presenting-accessibly.html) You can also check out this helpful [video](https://www.youtube.com/watch?v=wdf_QyUFGr0) by "The Accessibility Guy."

## 6. Reflect on what you learned

For each AT, consider: What is the AT? What are its strengths and weaknesses? What disabilities does it support? This article on the [POSITIVES Scale](https://adaptech.org/wp-content/uploads/abDevelopmentAndValidationOfThePOSITIVESscaleRe3.pdf) might help you answer this question. It has information about what accessibility ICT people with different disabilities report using that you can refer to (see pp. 47-52). You might find p. 79 interesting as well! 


Fill out the [assignment reflection template](finding-accessibility-template.html), making sure it is accessible. Here is a [UW web page about how to make accessible documents](https://www.washington.edu/accesstech/documents/) and a [UW video about how to make accessible documents](https://www.washington.edu/doit/videos/index.php?vid=67)

