---
layout: default
title: Assignments
description: Course assignments
---

* TOC
{:toc}

This class uses a combination of in class work, individual
assignments, and one larger project. Students spend a majority of the
class on a longer open ended final project that is more research
oriented. All of the assignments will have some minimum required
competencies (see the [syllabus]({{site.baseurl}}/index.html) and the
section on [competencies](#competencies) below) and students may
indicate a certain number of self-selected additional competencies
they wish to be assessed on.


# Short Required Assignments: 

1. [Finding AT Around Us](finding-accessibility.html): Students need to find first-person videos by
   people with disabilities about their use of standard or cutting
   edge AT technology, and then give an accessible presentation about
   what they find.  
2. [Research Paper Analysis](disabilityjustice.html): Analyize a reading using our model based approach
3. [Plain Language Summary](plain-language.html): Write a plain language description of a research paper abstract 
4. [Improve accessibility of a thing](technology-implementation.html): Make something (not necessarily disability focused) that already exists more accessible
<!-- 4. [Conduct an accessibility assesssment](website-report.html) (service learning opportunity) -->

<!-- # Choose your Own Adventure -->
<!-- These assignments serve multiple purposes including first -->
<!-- opportunities to practice many of the competencies as well as -->
<!-- providing students with a way to do useful voluntary work in support -->
<!-- of the disability community. These are generally weekend projects. -->
<!-- Students need to do at least twice, and this list is still -->
<!-- somewhat tentative. -->

<!-- 1. [Develop a set of benchmark tasks for testing GAI ableism](ai.html) -->
<!-- 2. [Create a custom accessibility support tool using fabrication](lasercutting.html) -->
<!-- <\!-- 4. [Build a better button](button.html) -\-> -->

# Larger Project
There will be a larger project that takes place over the entire quarter. Currently, we plan on 

- [Project proposals](project-proposals.html) due in week 5
- [Checkpoint presentations](project-checkpoint.html) in week 7
- [Checkpoint presentations](project-checkpoint.html) in week 10
- [Final presentatons and writeup](project-final.html) in Week 12 (i.e. finals week)

This project is fairly open ended.

# Competencies 
As described in the [syllabus]({{site.baseurl}}/index.html), your
grade in the class will be based on whether you achieve *non
competent*, *competent* or *excellent* in each of these topics,
averaged over all the times that you are assessed. 

Your scores on these competencies determine your grade in the class as follows:
- Base grade: Number of Competents/2.5 + Number of Excellents/2
- Final grade: Base grade - (Number of non competents/2)

## 1. Disability Model Analysis
We want you to demonstrate an ability to argue for how a given technology or research project, including your own, meets or fails to meet appropriate disability principles drawn from disability studies' [models of disability](https://books.google.com/books?hl=en&lr=&id=7inBEAAAQBAJ&oi=fnd&pg=PA17&dq=Shakespeare,+T.,+and+N.+Watson.+2001.+%E2%80%9CThe+Social+Model+of+Disability:+An+Outdated+Ideology%3F%E2%80%9D.%E2%80%9D+&ots=GRsD_zEq8B&sig=lzBhwThMZyur4r01nxJj9zoW0kM#v=onepage&q=Shakespeare%2C%20T.%2C%20and%20N.%20Watson.%202001.%20%E2%80%9CThe%20Social%20Model%20of%20Disability%3A%20An%20Outdated%20Ideology%3F%E2%80%9D.%E2%80%9D&f=false), disability justice's  [10 principles laid out by Sins Invalid](https://static1.squarespace.com/static/5bed3674f8370ad8c02efd9a/t/5f1f0783916d8a179c46126d/1595869064521/10_Principles_of_DJ-2ndEd.pdf), Liz Jackson's concept of a [disability dongle](https://blog.castac.org/2022/04/disability-dongle/), and so on.

{% details How to address this %}
To address this, you must specify which three principles you are using in your analysis, and then analyze a product (research or otherwise) using these models.  When you summarize a paper, or turn in a proposal, we will assess this competency. Your writing should be specific about which principals you are analyzing, define them, and explain how they apply.
{% enddetails %}

## 2. Familiarity with a Range of Accessibility technologies
You should demonstrate that you are expanding your familiarity with various accessibility technologies. You must do this at least three times and/or for at least three different AT cases.

{% details How to address this %}
Not all AT will count toward this assignment, and the teaching staff will determine what counts. Here are some things that would not count. Check with us if you have any questions.

- A technology you are already familiar with / using (i.e. if you are a screen reader user, don't ask to be assessed on your familiarity with screen readers)
- The technologies you ask to be evaluated on are very similar and/or address very similar accessibility needs. For example, if you ask to be evaluated on a web based screen reader, and then NVDA, those would be too similar. 
- The technologies you select are not used by disabled people. 
- Your description of these technologies does not demonstrate learning or investigation of disability use cases. 

Turn in a reflection telling us about AT you have presented about or used in your assignments. The reflection should include Information about how the AT works, users, and strengths and weaknesses of the AT.  Your reflection or presentation should demonstrate that it is currently in use by people with disabilities (i.e. through a first-person account). You should also demonstrate a nuanced understanding of the AT. For example, understanding that audiobooks are not only useful for BLV people but also used by people with dyslexia and what limitations exist in their availability or usefulness. 
{% enddetails %}


## 3. Finding First-Person Accounts of Accessibility Tech
You should be able to find first person accounts to motivate your research and arguments even before you consider approaching the disability community. A first person account is a description by a disabled person of their experiences, needs and goals with respect to an accessibility topic. Souch accounts are typically found on youtube, social media, or a blogging platform. 

{% details How to address this %}
A first person account is written or presented by someone who
- Uses this technology themselves on a regular basis
- Has a disability
- Describes first person concerns such as:
  - How do they the use device to meet their needs?
  - In what ways does it help?
  - In what ways does it fall short?
  - Is their use of the AT specific to needs in their life (i.e. commuting, work)?
  - What improvements or changes would they like to see?

A first person account that meets the requirements of this assignment is not
- a teaching video/presentation
- an advertisement.
- based on your personal experience 

Multiple assignments require finding first-person accounts. We will assess whether they qualify when we grade those assignments. You can also include first-person accounts in your reflection for your competency on Familiarity with a Range of Accessibility Technologies.

If you have an existing relationship with a disability community, early phase input from that community can also address this and is strongly encouraged in your research more generally. However, while we know that some of you may have engaged withor interviewed people with disabilities, we ask that explore what is on social media for this particular competency. 
{% enddetails %}

## 4. Application of Positive Disability Principals to Research 
This competency assess wheth your  understand and can summarize and critique the premise of accessibility or disability-related research in relation to the following concerns:

{% details How to address this %}
You should be able to summarize and critique accessibility research, including your own, on the following concerns:

1. Is it ableist
2. What parts of the work are accessible and what are not (for example, are both design tools, and their outputs accessible?)
3. Are people with disabilities engaged in guiding this work? At what stages?
4.  Is it being used to give control and improve agency for people with disabilities
5. Is it addressing the whole community (intersectionality, multiple disabled people, multiply disabled people)

You will be assessed on this based on things like paper summaries and based on your writeup of your final project, as well as our assessment of how well your final project embodies these goals.
{% enddetails %}

## 5. Accessible Document Creation
It is important that you know how to make sure that documents and presentations you create are accessible to everyone in your intended audience, including people with disabilities.

{% details How to address this %}
This applies to presentations, word documents, and pdfs. You’ll need to demonstrate this on at least one presentation and one assignment writeup that is long and complex enough to have headers and structure to achieve competency.

Best practices:
- Avoid visual clutter (e.g. use San serif fonts (for digital viewing), don’t have too many things on the page)
- Use headers and styles where appropriate. For example, in Microsoft Word these are built-in “styles” and in Google Docs you can see these under “Format -> Paragraph Styles.” Headers should be nested like they are in HTML (e.g., H2 after and H1). Read this for more guidance in [how to do styles in Word](https://support.microsoft.com/en-us/office/make-your-word-documents-accessible-to-people-with-disabilities-d9bf3683-87ac-47ea-b91a-78dcacb3c66d#bkmk_builtinheadings_win)
- Use proper color contrast. 
- Write alt text for all non-decorative photos.
- Use meaningful hyperlink text Good example: check out [this class's syllabus]({{site.baseurl}}); Bad examples: check out this class's syllabus [here]({{site.baseurl}}); check out this class's sylabus: [{{site.baseurl}}]({{site.baseurl}})
- Properly mark up tables
- Screen reader order is correct (in documents where it applies, such as Powerpoint)

You will be assessed on this any time you turn in a required document. In addition, inaccessible documents may not be assessed for other competencies until they are made accessible.
{% enddetails %}


## 6. Accessible Presenting
You should be able to present accessibly, following [best practices](https://www.washington.edu/doit/making-your-presentation-accessible). As with accessible document creation this ensures that everyone in your intended audience, including people with disabilities, can participate in what you are doing.

{% details How to address this %}
Follow these guidelines:
1. Introduce and describe yourself
2. Speak slowly and clearly
3. Read entire quotes
4. Clearly describe images and videos so that someone who cannot see the screen can understand them
5. Spell acronyms and avoid or define terms, jargon, and idioms.
6. Repeat questions for clarity 
7. Slides are available to Audience 24 hrs ahead of presentation

<iframe width="560" height="315" src="https://www.youtube.com/embed/L9TxhGv91kc?si=gTEEKwMk6C5rAiW5" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>

How to demonstrate this competency: Tell us at least 24 hours ahead of time that you want to be evaluated on this competency and in what context (office hours, a classroom presentation, etc). It should be a situation in which we can record the presentation. 
{% enddetails %}

## 7. Image Description
Image descriptions should be concise, complete and accurate. You should use best practices to decide when to mention the background, describe people, and so on. You should learn to do this for various types including pictures, diagrams, screen shots, and so on in an accessible fashion. 

{% details How to address this %}
You will be evaluated on this any time you turn in a document that has images in it. You can also ask us to assess a specific image description in some other context.
{% enddetails %}

## 8. Sharing Research Back: Plain Language
Plain language writing is part of ethical research in accessibility, namely to share research with the accessibility community. Please pick at least four guidelines to focus on from the following list and specify which four you picked. You can address more to reach a higher competency score. Follows best practices for text simplification  as described on the [federal text simplification website](https://www.plainlanguage.gov/guidelines/)

{% details How to address this %}
Guidelines we will assess:

Use simple words
- Use positive language
- Use short paragraphs
- Use short sentences
- Avoid jargon
- Use active voice
- Use present tense
- Use examples
- Use headers
- Use transition words
How this will be assessed: You should tell us when you use plain language writing, and ask us to assess. There will be multiple opportunities to do this during the quarter.
{% enddetails %}





