---
layout: assignment
published: true

title: Final Project Proposal
revised: October 30, 2024

description: Propose a project to make the world slightly more accessible

---
* TOC
{:toc}

# Overview

The goal of your final project is to build an accessibility technology or make an existing technology more accessible, in a group of 2-4 students. In this phase of the final project, you will propose a specific project idea that you come up with.
<!-- The final project is a *group assignment* and requires forming groups of 2-4 people *who can all attend the same section*. Groups must be finalized by Friday, 11/8; if you already know who you are working with, you can submit your proposal as a group, but proposals may be submitted individually if you are not part of a group yet.  -->

Your idea should offer develop technology that will help to advance the needs of people with disabilities. However, we want to avoid creating [Disability Dongles](https://blog.castac.org/2022/04/disability-dongle/). To avoid this, we do two important things
1. You should inform your project from a first person account. If you cannot find first person commentary on the topic, please reach out to the course staff for help. We may tell you not to worry about it, or point you at resources such as research papers that have interviews of people with disabilities in them.
2. You should embody *Positive Disability Principles:* We understand that you cannot necessarily address all of the positive disability principles that we discuss in class, but at the very least you should be able to argue for principles 1 and 4: (1) It is not ableist (4) It furthers disabled agency and control. Ideally, you will also be able to address at least one more principle of the five [specified in the competency](index.html#4-application-of-positive-disability-principals-to-research).

*Note on disability involvement in this project:* It is not feasible to do a full iterative design cycle in this project (and not necessarily an ethical use of the time of people with disabilities).  Please reach out to us for permission if you intend to work with disabled participants. Otherwise we will expect you to base your project on first person accounts you find online.


{% details Final Project Examples from past Undergraduate and Masters Accessibility Courses %}
Some examples of what people have done in the past include:
- [Alti Discord Bot](https://courses.cs.washington.edu/courses/cse493e/23au/projects/alti.html).  Alti is a Discord bot that automatically generates alt text for any image that gets uploaded onto Discord. Once you add Alti to your Discord server, Alti will automatically generate alt text for the image using artificial intelligence (AI). [Demo](https://alti-9e674.web.app/)
- [Complexion Cupid: Color Matching Foundation Program](https://courses.cs.washington.edu/courses/cse493e/23au/projects/complexion-cupid.html). Allows individuals with color blindness to upload an image of their skin, and provides a makeup foundation match. Additionally, individuals can upload existing swatches and will be provided with filtered photos that better show the matching accuracy. [Source](https://github.com/catamtz3/uwimg2)
- [Twitter Content Warnings](https://courses.cs.washington.edu/courses/cse493e/23au/projects/content-scanner.html). A chrome extension meant to be used in conjunction with twitter.com in order to help people with PTSD
- [Lite Lingo: Plain Text Translator](https://courses.cs.washington.edu/courses/cse493e/23au/projects/lite-lingo.html). A plain text translator to help individuals with learning disabilities. [Demo](https://ryanvanle.github.io/lite-lingo-website/) and  [Source](https://github.com/ryanvanle/lite-lingo-extension)
- [Matplotalt: Alt text for matplotlib figures](https://courses.cs.washington.edu/courses/cse493e/23au/projects/matplotalt.html). A small python package to generate and surface alt text for matplotlib figures and improving [chart accessibility](https://accessiplot.readthedocs.io/en/latest/)
- [PadMap: Accessible Map for Menstrual Products](https://courses.cs.washington.edu/courses/cse493e/23au/projects/padmap.html) Our goal is to ensure that anywhere on campus, people can search up the closest free menstrual products to them and get there in an accessible way. [Source](https://github.com/kirstenmg/padmap)
- [SpeechIT](https://courses.cs.washington.edu/courses/cse493e/23au/projects/speaker-notes.html). A presentation speech checker to ensure a user’s verbal speech during presentation is accessible and understandable for everyone.
- [Make Arduino programming more accessible](https://uwcse-nsds.github.io/arduino-a11y/) by visualizing output from its sensors accessible and creating [tactile schematics](https://www.hackster.io/monica/creating-tactile-schematics-using-fritzing-5b47f8) for circuits
{% enddetails %}

## Group Formation

The final project is a *group assignment* and requires forming groups of 2-4 people *who can all attend the same section*. (You don't necessarily need to be registered for the same section, but you must all be able to attend the same one.)

Groups must be finalized by Friday, 11/8. If you already know who you are working with, you can submit your proposal as a group, but proposals may be submitted individually if you are not part of a group yet.

To help with group formation, [post a summary of your idea on Ed]({{site.discussion}}/5583557); you'll have opportunities to talk with other students in your section and browse their idea summaries so that you can find people who are interested in similar topics.

## Learning Goals / Competencies
Required Competencies for this homework:

- Accessible Document Creation
- Positive Disability Principals
- Disability Justice Analysis
- Finding First Person Accounts of Accessibility Tech

Optionally, if you complete the requirements for it, you can add any other competency.

# Turnin
1. [Submit your proposal on Canvas]({{site.submit}}/9698194). Your write up should include the following information:
   1. What will you do? What first person evidence did you find for this idea? Provide a brief summary and links.
   2. Does this first person account meet the requirements for a first person account? [Competency: Finding First Person Accounts]
   3. How does this project embody Positive Disability Principles? [Competency: Positive Disability Principles]
   4. Pick 3 of Sins Invalid's 10 disability justice principals. How does this project fail, or succeed, in embodying them? [Competency: Disability Justice Analysis]
   5. How will this be feasible (timeline, etc.)? What do you plan to accomplish by each of the project milestones (checkpoint 1, checkpoint 2, final presentation/handin)?
   6. Include a statement of what your contributions were for each of the parts of the proposal if you did this as a group.
2. (Not graded) Post a summary of your idea for others to see on [Ed]({{site.discussion}}/5583557) to help with group formation.




