---
layout: assignment
published: true

title: Website/App Accessibility Assessment (Individual)
description: Learn to assess website/app accessibility using a variety of technologies
revised: Oct 9, 2024

---
* TOC
{: toc}

# Overview
The goal of this homework is to learn about basics of website accessibility and how to assess. In part 1, you: Learn how to use automated tools (and their limitations); Learn how to address the limitations of automated tools using accessibility tools; In part 2, you: Learn how to write up an assessment and prioritize what problems to fix; Practice identifying paths to fixing problems. You will also have the opportunity to practice UI image description. 

## Competencies
This homework may contribute to your competency grade on 
- Accessibility Technology Familiarity
- Automated Accessibility Checking
- Accessibility Rules 
- Accessible Document Creation
- Image Description

**NOTE** if you want to be re-assessed on your first person account competency (or any other competency). this is an opportunity o resubmit it. However, you will need to follow the instructions for re-assessment in the [canvas outcomes]({{site.canvas}}/outcomes) to receive credit for this. 

## Length & Difficulty
Students in the past have reported that this assignment took them a median of 7 hours.  A challenge that multiple students faced is summarizing the WCAG guidelines in their own words. Please be sure to do so, *or* to quote and reference WCAG guidelines according to our [course policy on academic conduct]({{site.baseurl}}/academic-conduct.html). Some things that students have told us about this assignment:
<!-- - It helps to use the [Usability Access Report (UAR) template](webegs/UAR_Template.doc) when filling out the UARS. -->
- It helps to use the [Usability Access Report (UAR) template](uar-template.html) when filling out the UARS.
- It was surprising to realize how many issues even websites that try to take accessibility into account still miss! 

Here is a [sample set of UARs from a prior student](webegs/DDUARS.docx) who kindly shared them with us for you to look at, and here is a [sample set of UARs that we provide](https://docs.google.com/document/d/1UYcPtI8SHrq2Tt6x0cS3-lW2c0h47YCn8Lz6spcuqfg/view) for you to look at.

# Turnin

1. Complete the assignment as described below 
2. [Submit]({{site.submit}}) your reflection using this [template outline](website-template.html) and your UARs using this [UAR template](uar-template.html)

# Details
Your goal is to generate a range of Usability Aspect Reports documenting accessibility concerns (and perhaps successes) with a website or app. You will use [W3C guidelines](https://www.w3.org/WAI/standards-guidelines/) for the site or app you are assessing. 

The most relevant are probably [WCAG
2.1](https://www.w3.org/WAI/standards-guidelines/wcag/glance/) and
[How WCAG 2.0 Applies to
Mobile](https://www.w3.org/TR/mobile-accessibility-mapping/) (even
websites may be used in mobile settings). If you are working on a
mobile app, you should also review this PDF (specifically page
9): [Epidemiology as a Framework for Large-Scale Mobile Application
Accessibility
Assessment](https://xiaoyizhang.me/assets/Paper/ASSETS_2017_Epidemiology.pdf).

Optional readings:
 - the Anatomy of the YouDescribe welcome page section of the [tutorial](https://youdescribe.org/support/tutorial)


## 0. Look over your assigned website and select 3 tasks
You will be assigned to one of eight websites that were submitted by external organizations for review. Please see Canvas for your specific assignment group. Note that this is *not* a group project, we are asking you to individually work on your assigned website this week. You will join forces *next* week with others in your section assigned to the same website, to write a report. 

You will need to select what aspect of this site to test, you should have at least 3 different well defined tasks that you test. For example, you might select tasks such contacting support, and finding information about accessibility. Be sure to select tasks that are relevant to the website and any requests the submitter made.

{% details List of Websites %}
- [Paswitive Alliance](https://www.pawsitivealliance.org/): "Working across Washington  to help homeless pets find loving homes, and prevent cats and dogs from becoming homeless." This is a website assessment. 
- [Emerald City Athletics](https://emeraldcityathletics.com/): "Our mission is to lead our members in the Seattle area to holistic fitness and health through achieving their desired results. We’re not just talking about weight on the bar or pounds on the scale, but the kind of holistic health that translates to physical, emotional, mental, and spiritual strength." This is a website assessment. 
- [Scientist Rebellion](https://scientistrebellion.org/): "We are scientists uniting against climate change" This is a website assessment. 
- [GSBA](https://thegsba.org/): "Our mission: To combine business development, leadership and social action to expand economic opportunities for the lesbian, gay, bisexual, transgender, and queer community and those who support equality for all." This is a website assessment. 
- [KBCS.fm](https://www.kbcs.fm/) "Connecting you to music and ideas." This is a website assessment project. 
- [Snohomish County Auditors Office](https://snohomishcountywa.gov/224/Elections-Voter-Registration) "We want to embark on updating our website, but leadership isn't 100% convinced yet that this is necessary. This assessment would help to further make our case that an update is essential to improving accessibility of our services."
- [Thurston County Board of Commissioners](https://www.thurstoncountywa.gov/departments/board-county-commissioners) "The Board of County Commissioners is the county's legislative authority. The five commissioners are elected to four-year terms and serve as the chief administrators for several important county operations, including oversight of the county's budget."
- [CSE 493e Website]({{site.baseurl}}). Help us make it better!
- [Euki](https://play.google.com/store/apps/details?id=com.kollectivemobile.euki): "Euki is the first app of its kind to offer comprehensive sexual and reproductive health information" This is a mobile app that only runs on the android platform. 
- [Playscout playground finder](https://play.google.com/store/apps/details?id=com.adaventuresllc.playscout&utm_source=substack&utm_medium=email&pli=1) "Find playgrounds near you with PlayScout! Join the community-driven playground finder app designed for people wondering 'where should I take my kids today?'". This is a mobile app that only runs on the android platform. 
{% enddetails %}

## 1. Conduct an accessibility audit
An accessibility audit involves a combination of automated testing and testing with accessibility tools. Here is an example video describing how to do an audit:

<iframe width="560" height="315" src="https://www.youtube.com/embed/ouhMYvtrzsg?si=wmzyPLJwHU6jr81t" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>

### 1.1 Collect data on  accessibility problems using an automated accessibility checker

For each of these steps, you will record data about what you find so that you can complete the write up at the end.

You should run the website and/or app through an accessibility checker. The WebAim accessibility checker, [WAVE](https://wave.webaim.org/), is a great choice for many sites. However, if the site requires that you log in, you may need an alternative. A great choice is the [Axe Chrome plugin](https://chrome.google.com/webstore/detail/axe-devtools-web-accessib/lhdoppojpmngadmnindnejefpokejbdd?hl=en-US). 

To install the Accessibility Scanner on android, search for it in the
Play Store and install it on your device or emulator. The installation
process will be the same for a physical phone or the emulator equipped
with the Play Store. Follow the instructions on the [Getting started
with Google Accessibility
Scanner](https://support.google.com/accessibility/android/answer/6376570?hl=en&ref_topic=6376582)
page to get the scanner working on your device. Another option is to
install the Android Accessibility Suite which contains both the
Accessibility Scanner and TalkBack if it has not been installed
before.

There is currently no IOS support for testing an application you do not have the source code for. 

You should generate 2-4 UARs from this phase of the project. If there are multiple similar problems (such as missing ALT text for multiple images), summarize them all in a single UAR.

### 1.2 Collect data on accessibility problems using accessibility technologies

First you will need to decide which *two* accessibility technologies you will use. Pick two accessibility technologies.  The technologies you choose should provide different information from each other. For example, tabbing through the website will not provide different information than a screen reader, since a screen reader should not be used with a mouse.  Most people select a screen reader, and magnification or voice input. If you already use one of these technologies on a regular basis, please check in with the course staff about best choices.

Here are some example resources that may help you in gaining comfort with these accessibility technologies 
- [Setting up a screen reader testing environment](https://www.sarasoueidan.com/blog/testing-environment-setup/)
- [Zoomtext and other magnification in use](https://www.youtube.com/watch?v=4ZRVDgeMpXc) and [Setting up windows for zooming](https://www.youtube.com/watch?v=TQhUCnMhDZE)
- [Screen reading intro](https://axesslab.com/what-is-a-screen-reader/)
- Switch control intro: [Switch Control overview](https://www.youtube.com/watch?v=GQKEE9nI1lk)
- Advanced voice based input: [voice programming](https://www.youtube.com/watch?v=YKuRkGkf5HU)

Note: UW has given us accessible (human captioned) versions of several of these videos, you can find the link on Canvas for those videos.

Once you have picked your technologies, collect data on accessibility problems using the two accessibility technologies. You should find at least one new   <!-- - Change this to 2 each next year -->
 problem with each AT, that you did not already find with the automated tool. If you cannot find any problems, reach out to the staff for approval and we will help you identify a success category you can write up in a UAR that demonstrates how well that AT is supported. 

## 2.  Record the data in a *Usability Aspect Report*
<!-- Record each group of similar issues you find using this [Usability Aspect Report Template](webegs/UAR_Template.doc). Here is a [sample set of UARs](webegs/DDUARS.docx) that a prior student has kindly shared with us for you to look at. Make sure that your UARs are accessible. Be sure to include problems that you found with an automated tool *and* things that you could only find using manual testing with a your accessibility technologies. -->
Record each group of similar issues you find using this [Usability Aspect Report Template](uar-template.html). 
<!-- Here is a [sample set of UARs](webegs/DDUARS.docx) that a prior student has kindly shared with us for you to look at.  -->
Make sure that your UARs are accessible. Be sure to include problems that you found with an automated tool *and* things that you could only find using manual testing with a your accessibility technologies.

<!-- Some key things to make note of: 
- **Good or Bad Feature** *If your website as very accessible* you may include UARS for particularly good features 
- **Source** including *your initials*; *the type of AT used*; and a unique ID. For example, JM-SR-3 (which means, approximately, Jennifer Mankoff Screen Reader UAR # 3).
- **Name/Brief Description** Provide a very brief name/summary. This should include the **WCAG guideline or guidelines that this violates
**
- **Evidence** Specify the guideline violated and provide a screen shot with ALT text or other evidence of the violation. 
- **Explanation** Explain why this is a problem (or good aspect).
- **Severity** Rank severity (with 4 being catastrophe) 
- **Justification** Justify your ranking in terms of *frequency*, *impact* and *persistence*
- **Relationship to other problems** If this is related to/caused by/causes other problems you record, you can give their *source* number here
 -->
